@@ -44,8 +44,6 @@ class QWidget;
 
 const int MIN_HOURS_DAILY_INDEX_IN_ARRAY=1;
 
-extern bool haveStudentsMinHoursDailyRealDaysAllowEmptyDays;
-
 extern Matrix1D<QSet<int>> tmpPreferredRealRooms;
 extern Matrix1D<bool> tmpFoundNonEmpty;
 
@@ -288,6 +286,13 @@ bool computeMaxDaysPerWeekForStudents(QWidget* parent);
 ////////END   teachers max days per week
 
 
+//2025-05-30
+extern Matrix1D<int> teachersMaxHoursPerTermMaxHours; //-1 for not existing
+extern Matrix1D<double> teachersMaxHoursPerTermWeightPercentages; //-1 for not existing
+extern Matrix1D<QList<int>> teachersWithMaxHoursPerTermForActivities;
+bool computeMaxHoursPerTermForTeachers(QWidget* parent);
+
+
 ////////BEGIN teachers no two consecutive days
 //activities indices (in 0..gt.rules.nInternalActivities-1) for each teacher
 extern Matrix1D<double> teachersNoTwoConsecutiveDaysPercentages; //-1 for not existing
@@ -472,6 +477,31 @@ void computeActivitiesNotOverlapping();
 ////////END   activities not overlapping
 
 
+//BEGIN teacher(s) pair of mutually exclusive time slots
+extern bool haveTeachersPairOfMutualExclusiveTimeSlots;
+
+extern Matrix1D<QList<double>> teachersPairOfMutuallyExclusiveTimeSlotsPercentages;
+extern Matrix1D<QList<int>> teachersPairOfMutuallyExclusiveTimeSlotsDay1;
+extern Matrix1D<QList<int>> teachersPairOfMutuallyExclusiveTimeSlotsHour1;
+extern Matrix1D<QList<int>> teachersPairOfMutuallyExclusiveTimeSlotsDay2;
+extern Matrix1D<QList<int>> teachersPairOfMutuallyExclusiveTimeSlotsHour2;
+
+bool computeTeachersPairOfMutuallyExclusiveTimeSlots(QWidget* parent);
+//END   teacher(s) pair of mutually exclusive time slots
+
+//BEGIN students(s) pair of mutually exclusive time slots
+extern bool haveStudentsPairOfMutualExclusiveTimeSlots;
+
+extern Matrix1D<QList<double>> subgroupsPairOfMutuallyExclusiveTimeSlotsPercentages;
+extern Matrix1D<QList<int>> subgroupsPairOfMutuallyExclusiveTimeSlotsDay1;
+extern Matrix1D<QList<int>> subgroupsPairOfMutuallyExclusiveTimeSlotsHour1;
+extern Matrix1D<QList<int>> subgroupsPairOfMutuallyExclusiveTimeSlotsDay2;
+extern Matrix1D<QList<int>> subgroupsPairOfMutuallyExclusiveTimeSlotsHour2;
+
+bool computeSubgroupsPairOfMutuallyExclusiveTimeSlots(QWidget* parent);
+//END   students(s) pair of mutually exclusive time slots
+
+
 ////////BEGIN teacher(s) max hours daily
 extern Matrix1D<double> teachersMaxHoursDailyPercentages1;
 extern Matrix1D<int> teachersMaxHoursDailyMaxHours1;
@@ -1116,6 +1146,35 @@ void computeMustComputeTimetableTeachers();
 bool homeRoomsAreOk(QWidget* parent);
 
 
+//2025-04-02
+class TwoSetsOfActivitiesSameSections_item
+{
+public:
+	//double weight; -> must be 100.0%
+	QList<int> activitiesAList;
+	QHash<int, int> activitiesAHash;
+
+	QList<int> activitiesBList;
+	QHash<int, int> activitiesBHash;
+
+	//not really needed
+	/*QList<int> aTimeSlotsList;
+	QSet<int> aTimeSlotsSet;
+
+	QList<int> bTimeSlotsList;
+	QSet<int> bTimeSlotsSet;*/
+
+	//QList<int> oTimeSlotsList;
+	QSet<int> oTimeSlotsSet; //exception slots
+};
+
+//We need the references to the elements to be valid, so we need this to be a std::list
+extern std::list<TwoSetsOfActivitiesSameSections_item> assabList;
+extern Matrix1D<QList<TwoSetsOfActivitiesSameSections_item*>> assabListForActivity;
+
+bool computeTwoSetsOfActivitiesSameSections(QWidget* parent);
+
+
 //2011-09-25 - Constraint activities occupy max time slots from selection
 class ActivitiesOccupyMaxTimeSlotsFromSelection_item
 {
@@ -1190,6 +1249,9 @@ extern Matrix1D<QList<ActivitiesMinSimultaneousInSelectedTimeSlots_item*>> amins
 
 bool computeActivitiesMinSimultaneousInSelectedTimeSlots(QWidget* parent);
 
+extern bool haveTwoSetsOfActivitiesSameSections;
+extern Matrix1D<bool> activityHasTwoSetsOfActivitiesSameSections;
+
 extern bool haveActivitiesOccupyMaxConstraints;
 extern Matrix1D<bool> activityHasOccupyMaxConstraints;
 
@@ -1490,13 +1552,53 @@ bool computeActivitiesSameRoomIfConsecutive(QWidget* parent);
 
 /////////////////////////////////////////////////////////////////////////
 
+//2025-05-15
+class SubgroupMaxSingleGapsInSelectedTimeSlots_item
+{
+public:
+	int maxSingleGaps;
+	QList<int> selectedTimeSlotsList;
+	QSet<int> selectedTimeSlotsSet;
+};
+
+//We need the references to the elements to be valid, so we need this to be a std::list
+extern std::list<SubgroupMaxSingleGapsInSelectedTimeSlots_item> smsgistsList;
+extern Matrix1D<QList<SubgroupMaxSingleGapsInSelectedTimeSlots_item*>> smsgistsListForSubgroup;
+extern bool haveStudentsMaxSingleGapsInSelectedTimeSlots;
+
+extern Matrix1D<QList<int>> activitiesWithDuration1ForSubgroup;
+
+bool computeStudentsMaxSingleGapsInSelectedTimeSlots(QWidget* parent);
+
+/////////////////////////////////////////////////////////////////////////
+
+//2025-05-17
+class TeacherMaxSingleGapsInSelectedTimeSlots_item
+{
+public:
+	int maxSingleGaps;
+	QList<int> selectedTimeSlotsList;
+	QSet<int> selectedTimeSlotsSet;
+};
+
+//We need the references to the elements to be valid, so we need this to be a std::list
+extern std::list<TeacherMaxSingleGapsInSelectedTimeSlots_item> tmsgistsList;
+extern Matrix1D<QList<TeacherMaxSingleGapsInSelectedTimeSlots_item*>> tmsgistsListForTeacher;
+extern bool haveTeachersMaxSingleGapsInSelectedTimeSlots;
+
+extern Matrix1D<QList<int>> activitiesWithDuration1ForTeacher;
+
+bool computeTeachersMaxSingleGapsInSelectedTimeSlots(QWidget* parent);
+
+/////////////////////////////////////////////////////////////////////////
+
 //2019-11-20
 class SubgroupActivityTagMinHoursDaily_item
 {
 public:
 	int activityTag;
 	int minHoursDaily;
-	bool allowEmptyDays;
+	int minDaysWithTag;
 	int durationOfActivitiesWithActivityTagForSubgroup;
 };
 
@@ -1513,7 +1615,7 @@ class TeacherActivityTagMinHoursDaily_item
 public:
 	int activityTag;
 	int minHoursDaily;
-	bool allowEmptyDays;
+	int minDaysWithTag;
 	int durationOfActivitiesWithActivityTagForTeacher;
 };
 
