@@ -67,14 +67,14 @@ QString Subject::getXmlDescription()
 QString Subject::getDescription()
 {
 	QString s=tr("N:%1", "The (short) name of the subject").arg(name);
-	s+=" ,";
+	s+=translatedCommaSpace();
 	s+=tr("LN:%1", "The long name of the subject").arg(longName);
-	s+=" ,";
+	s+=translatedCommaSpace();
 	s+=tr("C:%1", "The code of the subject").arg(code);
 	
 	QString end=QString("");
 	if(!comments.isEmpty())
-		end=", "+tr("C: %1", "Comments").arg(comments);
+		end=translatedCommaSpace()+tr("C: %1", "Comments").arg(comments);
 	
 	return s+end;
 }
