@@ -299,7 +299,9 @@ class AddOrModifyTimeConstraint: public QObject
 	QSet<QString> thirdFilter_showedStudents;
 
 public:
-	AddOrModifyTimeConstraint(QWidget* parent, int _type, TimeConstraint* _oldtc=nullptr);
+	AddOrModifyTimeConstraint(QWidget* parent, int _type, TimeConstraint* _oldtc=nullptr,
+	 const QString& _preselectedTeacherName=QString(), const QString& _preselectedStudentsSetName=QString(), const QString& _preselectedActivityTagName=QString(),
+	 const QString& _preselectedFirstActivityTagName=QString(), const QString& _preselectedSecondActivityTagName=QString());
 	~AddOrModifyTimeConstraint();
 
 private:
