@@ -31,7 +31,7 @@
 
 #include <QInputDialog>
 
-#include <QPlainTextEdit>
+#include <QTextEdit>
 
 #if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QRegularExpression>
@@ -50,6 +50,7 @@
 #include <QObject>
 #include <QMetaObject>
 
+#include <QBrush>
 #include <QPalette>
 
 #include <algorithm>
@@ -308,15 +309,23 @@ void AllSpaceConstraintsForm::moveSpaceConstraintUp()
 	
 	gt.rules.addUndoPoint(tr("A constraint was moved up:\n\n%1", "%1 is the detailed description of the constraint").arg(sc1->getDetailedDescription(gt.rules)));
 	
-	if(sc2->active)
-		constraintsListWidget->item(i)->setBackground(constraintsListWidget->palette().base());
-	else
-		constraintsListWidget->item(i)->setBackground(constraintsListWidget->palette().alternateBase());
+	if(sc2->active){
+		constraintsListWidget->item(i)->setBackground(QBrush());
+		constraintsListWidget->item(i)->setForeground(QBrush());
+	}
+	else{
+		constraintsListWidget->item(i)->setBackground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::Window));
+		constraintsListWidget->item(i)->setForeground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::WindowText));
+	}
 
-	if(sc1->active)
-		constraintsListWidget->item(i-1)->setBackground(constraintsListWidget->palette().base());
-	else
-		constraintsListWidget->item(i-1)->setBackground(constraintsListWidget->palette().alternateBase());
+	if(sc1->active){
+		constraintsListWidget->item(i-1)->setBackground(QBrush());
+		constraintsListWidget->item(i-1)->setForeground(QBrush());
+	}
+	else{
+		constraintsListWidget->item(i-1)->setBackground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::Window));
+		constraintsListWidget->item(i-1)->setForeground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::WindowText));
+	}
 
 	constraintsListWidget->setCurrentRow(i-1);
 	constraintChanged(/*i-1*/);
@@ -364,15 +373,23 @@ void AllSpaceConstraintsForm::moveSpaceConstraintDown()
 	
 	gt.rules.addUndoPoint(tr("A constraint was moved down:\n\n%1", "%1 is the detailed description of the constraint").arg(sc1->getDetailedDescription(gt.rules)));
 	
-	if(sc2->active)
-		constraintsListWidget->item(i)->setBackground(constraintsListWidget->palette().base());
-	else
-		constraintsListWidget->item(i)->setBackground(constraintsListWidget->palette().alternateBase());
+	if(sc2->active){
+		constraintsListWidget->item(i)->setBackground(QBrush());
+		constraintsListWidget->item(i)->setForeground(QBrush());
+	}
+	else{
+		constraintsListWidget->item(i)->setBackground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::Window));
+		constraintsListWidget->item(i)->setForeground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::WindowText));
+	}
 
-	if(sc1->active)
-		constraintsListWidget->item(i+1)->setBackground(constraintsListWidget->palette().base());
-	else
-		constraintsListWidget->item(i+1)->setBackground(constraintsListWidget->palette().alternateBase());
+	if(sc1->active){
+		constraintsListWidget->item(i+1)->setBackground(QBrush());
+		constraintsListWidget->item(i+1)->setForeground(QBrush());
+	}
+	else{
+		constraintsListWidget->item(i+1)->setBackground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::Window));
+		constraintsListWidget->item(i+1)->setForeground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::WindowText));
+	}
 
 	constraintsListWidget->setCurrentRow(i+1);
 	constraintChanged(/*i+1*/);
@@ -413,10 +430,13 @@ void AllSpaceConstraintsForm::filterChanged()
 		assert(filterOk(ctr));
 		constraintsListWidget->addItem(ctr->getDescription(gt.rules));
 
-		if(ctr->active)
+		if(ctr->active){
 			n_active++;
-		else
-			constraintsListWidget->item(constraintsListWidget->count()-1)->setBackground(constraintsListWidget->palette().alternateBase());
+		}
+		else{
+			constraintsListWidget->item(constraintsListWidget->count()-1)->setBackground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::Window));
+			constraintsListWidget->item(constraintsListWidget->count()-1)->setForeground(constraintsListWidget->palette().brush(QPalette::Disabled, QPalette::WindowText));
+		}
 	}
 
 	if(constraintsListWidget->count()<=0)
@@ -463,572 +483,11 @@ void AllSpaceConstraintsForm::modifyConstraint()
 
 	assert(i<visibleSpaceConstraintsList.count());
 	SpaceConstraint* ctr=visibleSpaceConstraintsList.at(i);
-	
+
 	AddOrModifySpaceConstraint(this, ctr->type, ctr);
 
-	/*switch(ctr->type){
-		//1
-		case CONSTRAINT_BASIC_COMPULSORY_SPACE:
-			{
-				ModifyConstraintBasicCompulsorySpaceForm form(this, (ConstraintBasicCompulsorySpace*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//2
-		case CONSTRAINT_ROOM_NOT_AVAILABLE_TIMES:
-			{
-				ModifyConstraintRoomNotAvailableTimesForm form(this, (ConstraintRoomNotAvailableTimes*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//3
-		case CONSTRAINT_ACTIVITY_PREFERRED_ROOM:
-			{
-				ModifyConstraintActivityPreferredRoomForm form(this, (ConstraintActivityPreferredRoom*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//4
-		case CONSTRAINT_ACTIVITY_PREFERRED_ROOMS:
-			{
-				ModifyConstraintActivityPreferredRoomsForm form(this, (ConstraintActivityPreferredRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//5
-		case CONSTRAINT_STUDENTS_SET_HOME_ROOM:
-			{
-				ModifyConstraintStudentsSetHomeRoomForm form(this, (ConstraintStudentsSetHomeRoom*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//6
-		case CONSTRAINT_STUDENTS_SET_HOME_ROOMS:
-			{
-				ModifyConstraintStudentsSetHomeRoomsForm form(this, (ConstraintStudentsSetHomeRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//7
-		case CONSTRAINT_TEACHER_HOME_ROOM:
-			{
-				ModifyConstraintTeacherHomeRoomForm form(this, (ConstraintTeacherHomeRoom*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//8
-		case CONSTRAINT_TEACHER_HOME_ROOMS:
-			{
-				ModifyConstraintTeacherHomeRoomsForm form(this, (ConstraintTeacherHomeRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//9
-		case CONSTRAINT_SUBJECT_PREFERRED_ROOM:
-			{
-				ModifyConstraintSubjectPreferredRoomForm form(this, (ConstraintSubjectPreferredRoom*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//10
-		case CONSTRAINT_SUBJECT_PREFERRED_ROOMS:
-			{
-				ModifyConstraintSubjectPreferredRoomsForm form(this, (ConstraintSubjectPreferredRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//11
-		case CONSTRAINT_SUBJECT_ACTIVITY_TAG_PREFERRED_ROOM:
-			{
-				ModifyConstraintSubjectActivityTagPreferredRoomForm form(this, (ConstraintSubjectActivityTagPreferredRoom*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//12
-		case CONSTRAINT_SUBJECT_ACTIVITY_TAG_PREFERRED_ROOMS:
-			{
-				ModifyConstraintSubjectActivityTagPreferredRoomsForm form(this, (ConstraintSubjectActivityTagPreferredRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		///6 apr 2009
-		//13
-		case CONSTRAINT_ACTIVITY_TAG_PREFERRED_ROOM:
-			{
-				ModifyConstraintActivityTagPreferredRoomForm form(this, (ConstraintActivityTagPreferredRoom*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//14
-		case CONSTRAINT_ACTIVITY_TAG_PREFERRED_ROOMS:
-			{
-				ModifyConstraintActivityTagPreferredRoomsForm form(this, (ConstraintActivityTagPreferredRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		///
-		//15
-		case CONSTRAINT_STUDENTS_SET_MAX_BUILDING_CHANGES_PER_DAY:
-			{
-				ModifyConstraintStudentsSetMaxBuildingChangesPerDayForm form(this, (ConstraintStudentsSetMaxBuildingChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//16
-		case CONSTRAINT_STUDENTS_MAX_BUILDING_CHANGES_PER_DAY:
-			{
-				ModifyConstraintStudentsMaxBuildingChangesPerDayForm form(this, (ConstraintStudentsMaxBuildingChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//17
-		case CONSTRAINT_STUDENTS_SET_MAX_BUILDING_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintStudentsSetMaxBuildingChangesPerWeekForm form(this, (ConstraintStudentsSetMaxBuildingChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//18
-		case CONSTRAINT_STUDENTS_MAX_BUILDING_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintStudentsMaxBuildingChangesPerWeekForm form(this, (ConstraintStudentsMaxBuildingChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//19
-		case CONSTRAINT_STUDENTS_SET_MIN_GAPS_BETWEEN_BUILDING_CHANGES:
-			{
-				ModifyConstraintStudentsSetMinGapsBetweenBuildingChangesForm form(this, (ConstraintStudentsSetMinGapsBetweenBuildingChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//20
-		case CONSTRAINT_STUDENTS_MIN_GAPS_BETWEEN_BUILDING_CHANGES:
-			{
-				ModifyConstraintStudentsMinGapsBetweenBuildingChangesForm form(this, (ConstraintStudentsMinGapsBetweenBuildingChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//21
-		case CONSTRAINT_TEACHER_MAX_BUILDING_CHANGES_PER_DAY:
-			{
-				ModifyConstraintTeacherMaxBuildingChangesPerDayForm form(this, (ConstraintTeacherMaxBuildingChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//22
-		case CONSTRAINT_TEACHERS_MAX_BUILDING_CHANGES_PER_DAY:
-			{
-				ModifyConstraintTeachersMaxBuildingChangesPerDayForm form(this, (ConstraintTeachersMaxBuildingChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//23
-		case CONSTRAINT_TEACHER_MAX_BUILDING_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintTeacherMaxBuildingChangesPerWeekForm form(this, (ConstraintTeacherMaxBuildingChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//24
-		case CONSTRAINT_TEACHERS_MAX_BUILDING_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintTeachersMaxBuildingChangesPerWeekForm form(this, (ConstraintTeachersMaxBuildingChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//25
-		case CONSTRAINT_TEACHER_MIN_GAPS_BETWEEN_BUILDING_CHANGES:
-			{
-				ModifyConstraintTeacherMinGapsBetweenBuildingChangesForm form(this, (ConstraintTeacherMinGapsBetweenBuildingChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//26
-		case CONSTRAINT_TEACHERS_MIN_GAPS_BETWEEN_BUILDING_CHANGES:
-			{
-				ModifyConstraintTeachersMinGapsBetweenBuildingChangesForm form(this, (ConstraintTeachersMinGapsBetweenBuildingChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//27
-		case CONSTRAINT_ACTIVITIES_OCCUPY_MAX_DIFFERENT_ROOMS:
-			{
-				ModifyConstraintActivitiesOccupyMaxDifferentRoomsForm form(this, (ConstraintActivitiesOccupyMaxDifferentRooms*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//28
-		case CONSTRAINT_ACTIVITIES_SAME_ROOM_IF_CONSECUTIVE:
-			{
-				ModifyConstraintActivitiesSameRoomIfConsecutiveForm form(this, (ConstraintActivitiesSameRoomIfConsecutive*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//2019-11-14
-		//29
-		case CONSTRAINT_STUDENTS_SET_MAX_ROOM_CHANGES_PER_DAY:
-			{
-				ModifyConstraintStudentsSetMaxRoomChangesPerDayForm form(this, (ConstraintStudentsSetMaxRoomChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//30
-		case CONSTRAINT_STUDENTS_MAX_ROOM_CHANGES_PER_DAY:
-			{
-				ModifyConstraintStudentsMaxRoomChangesPerDayForm form(this, (ConstraintStudentsMaxRoomChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//31
-		case CONSTRAINT_STUDENTS_SET_MAX_ROOM_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintStudentsSetMaxRoomChangesPerWeekForm form(this, (ConstraintStudentsSetMaxRoomChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//32
-		case CONSTRAINT_STUDENTS_MAX_ROOM_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintStudentsMaxRoomChangesPerWeekForm form(this, (ConstraintStudentsMaxRoomChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//33
-		case CONSTRAINT_STUDENTS_SET_MIN_GAPS_BETWEEN_ROOM_CHANGES:
-			{
-				ModifyConstraintStudentsSetMinGapsBetweenRoomChangesForm form(this, (ConstraintStudentsSetMinGapsBetweenRoomChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//34
-		case CONSTRAINT_STUDENTS_MIN_GAPS_BETWEEN_ROOM_CHANGES:
-			{
-				ModifyConstraintStudentsMinGapsBetweenRoomChangesForm form(this, (ConstraintStudentsMinGapsBetweenRoomChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//35
-		case CONSTRAINT_TEACHER_MAX_ROOM_CHANGES_PER_DAY:
-			{
-				ModifyConstraintTeacherMaxRoomChangesPerDayForm form(this, (ConstraintTeacherMaxRoomChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//36
-		case CONSTRAINT_TEACHERS_MAX_ROOM_CHANGES_PER_DAY:
-			{
-				ModifyConstraintTeachersMaxRoomChangesPerDayForm form(this, (ConstraintTeachersMaxRoomChangesPerDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//37
-		case CONSTRAINT_TEACHER_MAX_ROOM_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintTeacherMaxRoomChangesPerWeekForm form(this, (ConstraintTeacherMaxRoomChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//38
-		case CONSTRAINT_TEACHERS_MAX_ROOM_CHANGES_PER_WEEK:
-			{
-				ModifyConstraintTeachersMaxRoomChangesPerWeekForm form(this, (ConstraintTeachersMaxRoomChangesPerWeek*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//39
-		case CONSTRAINT_TEACHER_MIN_GAPS_BETWEEN_ROOM_CHANGES:
-			{
-				ModifyConstraintTeacherMinGapsBetweenRoomChangesForm form(this, (ConstraintTeacherMinGapsBetweenRoomChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//40
-		case CONSTRAINT_TEACHERS_MIN_GAPS_BETWEEN_ROOM_CHANGES:
-			{
-				ModifyConstraintTeachersMinGapsBetweenRoomChangesForm form(this, (ConstraintTeachersMinGapsBetweenRoomChanges*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//41
-		case CONSTRAINT_TEACHER_ROOM_NOT_AVAILABLE_TIMES:
-			{
-				ModifyConstraintTeacherRoomNotAvailableTimesForm form(this, (ConstraintTeacherRoomNotAvailableTimes*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//for mornings-afternoons
-		//42
-		case CONSTRAINT_STUDENTS_SET_MAX_ROOM_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintStudentsSetMaxRoomChangesPerRealDayForm form(this, (ConstraintStudentsSetMaxRoomChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//43
-		case CONSTRAINT_STUDENTS_MAX_ROOM_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintStudentsMaxRoomChangesPerRealDayForm form(this, (ConstraintStudentsMaxRoomChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//44
-		case CONSTRAINT_TEACHER_MAX_ROOM_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintTeacherMaxRoomChangesPerRealDayForm form(this, (ConstraintTeacherMaxRoomChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//45
-		case CONSTRAINT_TEACHERS_MAX_ROOM_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintTeachersMaxRoomChangesPerRealDayForm form(this, (ConstraintTeachersMaxRoomChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//46
-		case CONSTRAINT_STUDENTS_SET_MAX_BUILDING_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintStudentsSetMaxBuildingChangesPerRealDayForm form(this, (ConstraintStudentsSetMaxBuildingChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//47
-		case CONSTRAINT_STUDENTS_MAX_BUILDING_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintStudentsMaxBuildingChangesPerRealDayForm form(this, (ConstraintStudentsMaxBuildingChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//48
-		case CONSTRAINT_TEACHER_MAX_BUILDING_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintTeacherMaxBuildingChangesPerRealDayForm form(this, (ConstraintTeacherMaxBuildingChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//49
-		case CONSTRAINT_TEACHERS_MAX_BUILDING_CHANGES_PER_REAL_DAY:
-			{
-				ModifyConstraintTeachersMaxBuildingChangesPerRealDayForm form(this, (ConstraintTeachersMaxBuildingChangesPerRealDay*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		////2024-02-09
-		//50
-		case CONSTRAINT_STUDENTS_MAX_BUILDING_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsMaxBuildingChangesPerDayInIntervalForm form(this, (ConstraintStudentsMaxBuildingChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//51
-		case CONSTRAINT_STUDENTS_SET_MAX_BUILDING_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsSetMaxBuildingChangesPerDayInIntervalForm form(this, (ConstraintStudentsSetMaxBuildingChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//52
-		case CONSTRAINT_TEACHERS_MAX_BUILDING_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeachersMaxBuildingChangesPerDayInIntervalForm form(this, (ConstraintTeachersMaxBuildingChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//53
-		case CONSTRAINT_TEACHER_MAX_BUILDING_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeacherMaxBuildingChangesPerDayInIntervalForm form(this, (ConstraintTeacherMaxBuildingChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//54
-		case CONSTRAINT_STUDENTS_MAX_BUILDING_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsMaxBuildingChangesPerRealDayInIntervalForm form(this, (ConstraintStudentsMaxBuildingChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//55
-		case CONSTRAINT_STUDENTS_SET_MAX_BUILDING_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsSetMaxBuildingChangesPerRealDayInIntervalForm form(this, (ConstraintStudentsSetMaxBuildingChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//56
-		case CONSTRAINT_TEACHERS_MAX_BUILDING_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeachersMaxBuildingChangesPerRealDayInIntervalForm form(this, (ConstraintTeachersMaxBuildingChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//57
-		case CONSTRAINT_TEACHER_MAX_BUILDING_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeacherMaxBuildingChangesPerRealDayInIntervalForm form(this, (ConstraintTeacherMaxBuildingChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		////2024-02-19
-		//58
-		case CONSTRAINT_STUDENTS_MAX_ROOM_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsMaxRoomChangesPerDayInIntervalForm form(this, (ConstraintStudentsMaxRoomChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//59
-		case CONSTRAINT_STUDENTS_SET_MAX_ROOM_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsSetMaxRoomChangesPerDayInIntervalForm form(this, (ConstraintStudentsSetMaxRoomChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//60
-		case CONSTRAINT_TEACHERS_MAX_ROOM_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeachersMaxRoomChangesPerDayInIntervalForm form(this, (ConstraintTeachersMaxRoomChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//61
-		case CONSTRAINT_TEACHER_MAX_ROOM_CHANGES_PER_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeacherMaxRoomChangesPerDayInIntervalForm form(this, (ConstraintTeacherMaxRoomChangesPerDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//62
-		case CONSTRAINT_STUDENTS_MAX_ROOM_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsMaxRoomChangesPerRealDayInIntervalForm form(this, (ConstraintStudentsMaxRoomChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//63
-		case CONSTRAINT_STUDENTS_SET_MAX_ROOM_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintStudentsSetMaxRoomChangesPerRealDayInIntervalForm form(this, (ConstraintStudentsSetMaxRoomChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//64
-		case CONSTRAINT_TEACHERS_MAX_ROOM_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeachersMaxRoomChangesPerRealDayInIntervalForm form(this, (ConstraintTeachersMaxRoomChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//65
-		case CONSTRAINT_TEACHER_MAX_ROOM_CHANGES_PER_REAL_DAY_IN_INTERVAL:
-			{
-				ModifyConstraintTeacherMaxRoomChangesPerRealDayInIntervalForm form(this, (ConstraintTeacherMaxRoomChangesPerRealDayInInterval*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//66
-		case CONSTRAINT_ROOM_MAX_ACTIVITY_TAGS_PER_DAY_FROM_SET:
-			{
-				ModifyConstraintRoomMaxActivityTagsPerDayFromSetForm form(this, (ConstraintRoomMaxActivityTagsPerDayFromSet*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//67
-		case CONSTRAINT_ROOM_MAX_ACTIVITY_TAGS_PER_REAL_DAY_FROM_SET:
-			{
-				ModifyConstraintRoomMaxActivityTagsPerRealDayFromSetForm form(this, (ConstraintRoomMaxActivityTagsPerRealDayFromSet*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		//68
-		case CONSTRAINT_ROOM_MAX_ACTIVITY_TAGS_PER_WEEK_FROM_SET:
-			{
-				ModifyConstraintRoomMaxActivityTagsPerWeekFromSetForm form(this, (ConstraintRoomMaxActivityTagsPerWeekFromSet*)ctr);
-				setParentAndOtherThings(&form, this);
-				form.exec();
-				break;
-			}
-		////
-		default:
-			QMessageBox::critical(this, tr("FET critical"), tr("You have found a bug in FET. Please report it. This kind of constraint"
-			 " is not correctly recognized in all space constraints dialog. FET will skip this error, so that you can continue work."
-			 " Probably the constraint can be modified from the specific constraint dialog."));
-			//assert(0);
-			//exit(1);
-			break;
-	}*/
-
 	filterChanged();
-	
+
 	constraintsListWidget->verticalScrollBar()->setValue(valv);
 	constraintsListWidget->horizontalScrollBar()->setValue(valh);
 
@@ -1356,7 +815,7 @@ void AllSpaceConstraintsForm::constraintComments()
 	
 	QVBoxLayout* vl=new QVBoxLayout();
 	
-	QPlainTextEdit* commentsPT=new QPlainTextEdit();
+	QTextEdit* commentsPT=new QTextEdit();
 	commentsPT->setPlainText(ctr->comments);
 	commentsPT->selectAll();
 	commentsPT->setFocus();
