@@ -399,16 +399,16 @@ void TimetableGenerateForm::stop()
 	s+=TimetableGenerateForm::tr("Please check the constraints related to the last "
 	 "activities in the list below, which might be impossible to schedule:");
 	s+="\n\n";
-	s+=TimetableGenerateForm::tr("Here are the placed activities which lead to an inconsistency, "
+	s+=TimetableGenerateForm::tr("Here are the placed activities which led to an inconsistency, "
 	 "in order from the first one to the last (the last one FET failed to schedule "
-	 "and the last ones are most likely impossible):");
+	 "and the last ones are most likely the difficult ones):");
 	s+="\n\n";
 	for(int i=0; i<gen.nDifficultActivities; i++){
 		int ai=gen.difficultActivities[i];
 
 		s+=TimetableGenerateForm::tr("No: %1").arg(i+1);
 
-		s+=", ";
+		s+=translatedCommaSpace();
 
 		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
 			.arg(gt.rules.internalActivitiesList[ai].id)
@@ -751,7 +751,7 @@ void TimetableGenerateForm::impossibleToSolve()
 
 		s+=TimetableGenerateForm::tr("No: %1").arg(i+1);
 
-		s+=", ";
+		s+=translatedCommaSpace();
 
 		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
 			.arg(gt.rules.internalActivitiesList[ai].id)
@@ -1277,16 +1277,16 @@ void TimetableGenerateForm::seeImpossible()
 	s+=TimetableGenerateForm::tr("Please check the constraints related to the last "
 	 "activities in the list below, which might be difficult to schedule:");
 	s+="\n\n";
-	s+=TimetableGenerateForm::tr("Here are the placed activities which lead to a difficulty, "
+	s+=TimetableGenerateForm::tr("Here are the placed activities which led to a difficulty, "
 	 "in order from the first one to the last (the last one FET failed to schedule "
-	 "and the last ones are difficult):");
+	 "and the last ones are probably difficult):");
 	s+="\n\n";
 	for(int i=0; i<gen.nDifficultActivities; i++){
 		int ai=gen.difficultActivities[i];
 
 		s+=TimetableGenerateForm::tr("No: %1").arg(i+1);
 
-		s+=", ";
+		s+=translatedCommaSpace();
 
 		s+=TimetableGenerateForm::tr("Id: %1 (%2)", "%1 is id of activity, %2 is detailed description of activity")
 			.arg(gt.rules.internalActivitiesList[ai].id)
