@@ -84,6 +84,10 @@ class TimetableGenerateMultipleForm : public QDialog, Ui::TimetableGenerateMulti
 	Q_OBJECT
 
 	QList<QLabel*> labels;
+	QList<QLabel*> pausedLabels;
+	
+	QList<QPushButton*> restartPushButtons;
+	QList<QPushButton*> pausePushButtons;
 	
 	//QList<Controller*> controllersList;
 	
@@ -108,6 +112,8 @@ public slots:
 	void help();
 
 	void start();
+	
+	void restartCurrentThread();
 
 	void stop();
 	
@@ -123,6 +129,10 @@ private slots:
 	void generationFinished();
 	
 	void activityPlaced(int nThread, int na);
+	
+	void seeInitialOrder();
+	
+	void pauseCurrentThread();
 };
 
 #endif
